#!/usr/bin/perl -w
use strict;
use warnings;
use utf8;

use Digest::HMAC qw/hmac_hex/;
use Digest::SHA qw/sha256/;
use POSIX 'strftime';
use Math::BaseCnv;

sub get_symantec_validation_base36 {
	my ($csr, $hmac_key, $signature_algorithm) = @_;
    # """
    # @param csr: The csr of the symantec order
    # @param hmac_key: The Shared Key
    # @return: The symantec value for the subpart except leading s (X.domain.ch)
    # for the DNS record or file content
    # """
    my $hmac_hex = hmac_hex($csr, $hmac_key, $signature_algorithm);
    # print "$hmac_hex\n";
    return lc cnv($hmac_hex, 16, 36);
}

sub get_symantec_dns_validation_subpart {
	my ($csr, $hmac_key) = @_;
    # """
    # @param csr: The csr of the symantec order
    # @param hmac_key: The Shared Key
    # @return: The symantec value for the subpart including leading s
    # (X.domain.com) for the DNS record
    # """
    my $timestamp = format_symantec_dns_timestamp();
    my $secret = $timestamp . $csr;
    my $dns_name = $timestamp . validate(get_symantec_validation_base36($secret, $hmac_key, \&sha256));
    return $dns_name;
}

sub get_symantec_file_validation_subpart {
	my ($csr, $hmac_key) = @_;
    # """
    # @param csr: The csr of the symantec order
    # @param hmac_key: The Shared Key
    # @return: The symantec value for the subpart including leading s
    # (X.domain.com) for the DNS record
    # """
    my $timestamp = format_symantec_dns_timestamp();
    my $secret = $timestamp . $csr;
    my $dns_name = validate(get_symantec_validation_base36($secret, $hmac_key, \&sha256));
    return $timestamp . $dns_name;
}

sub validate {
    my ($s) = @_;
    """
    Makes sure that the string is 50 characters long. Fill up with 0s if it's
    shorter.
    @param s: The DNS validation string
    @return: A 50 characters long DNS/File validation substring
    """
    my $expected_length = 50
    while length($s) < $expected_length:
        substr($s, 0, 0) = '0';
    return $s
}

sub format_symantec_dns_timestamp {

    return strftime '%Y%m%d%H%M%S', gmtime;
}

my $csr =$ARGV[0] ;
my $key = $ARGV[1];
print get_symantec_file_validation_subpart($csr, $key);