# coding=utf-8
import datetime
import logging
from hashlib import sha1, sha256
import hmac
import base36
import sys


def get_symantec_validation_base36(csr, hmac_key, signature_algorithm):
    """
    @param csr: The csr of the symantec order
    @param hmac_key: The Shared Key
    @return: The symantec value for the subpart except leading s (X.domain.ch)
    for the DNS record or file content
    """
    hashed = hmac.new(hmac_key, csr, signature_algorithm)
    logging.debug(hashed)
    base10 = int(hashed.hexdigest(), 16)
    logging.debug(base10)
    return base36.dumps(base10)


def get_symantec_dns_validation_subpart(csr, hmac_key, timestamp=None):
    """

    @param csr: The csr of the symantec order
    @param hmac_key: The Shared Key
    @return: The symantec value for the subpart including leading s
    (X.domain.com) for the DNS record
    """
    if timestamp == None:
        timestamp = format_symantec_dns_timestamp(datetime.datetime.utcnow())
    secret = timestamp + csr
    hashresult = validate(get_symantec_validation_base36(secret, hmac_key,
                                                           sha256))
    dns_name = '{}{}'.format(timestamp, hashresult)
    return dns_name

def get_symantec_file_validation_subpart(csr, hmac_key,timestamp=None):
    """

    @param csr: The csr of the symantec order
    @param hmac_key: The Shared Key
    @return: The symantec value for the subpart including leading s
    (X.domain.com) for the DNS record
    """
    if timestamp == None:
        timestamp = format_symantec_dns_timestamp(datetime.datetime.utcnow())
	#timestamp = "20170406124547"
    secret = timestamp + csr
    dns_name = "{}{}".format(timestamp, validate(get_symantec_validation_base36(secret, hmac_key, sha256)))
    return dns_name


def format_symantec_dns_timestamp(d):
    symantec_dns_timestamp_format = '%Y%m%d%H%M%S'
    assert isinstance(d, datetime.datetime)
    return d.strftime(symantec_dns_timestamp_format)


def validate(s):
    """
    Makes sure that the string is 50 characters long. Fill up with 0s if it's
    shorter.
    @param s: The DNS validation string
    @return: A 50 characters long DNS/File validation substring
    """
    expected_length = 50
    while len(s) < expected_length:
        s = s[:1] + "0" + s[1:]
    return s

if (__name__ == "__main__"):
	csr = sys.argv[1]
	key = sys.argv[2]
	print get_symantec_file_validation_subpart(csr, key)
